@@ -39,11 +39,20 @@ class Storage(driver.Base):
 
     @lru.get
     def get_content(self, path):
+        print "get_content path:"+path
         path = self._init_path(path)
-
         output = StringIO.StringIO()
         try:
-            return self._jss.bucket(self._bucket).get_Key(path)
+            object_instance = self._jss.bucket(self._bucket)
+            res = object_instance.download_flow()
+            while True:
+                data = res.read(1024)
+                if len(data) != 0:
+                    output.write(data)
+                else:
+                    break
+                    
+            return output.getvalue()
         except Exception as e:
             print e
             raise e
